Documentation
¶
Overview ¶
Package cors provides handlers to enable CORS support.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Allow ¶
func Allow(opts *Options) http.HandlerFunc
Allows CORS for requests those match the provided options.
Types ¶
type Options ¶
type Options struct {
// If set, all origins are allowed.
AllowAllOrigins bool
// A list of allowed origins. Wild cards and FQDNs are supported.
AllowOrigins []string
// If set, allows to share auth credentials such as cookies.
AllowCredentials bool
// A list of allowed HTTP methods.
AllowMethods []string
// A list of allowed HTTP headers.
AllowHeaders []string
// A list of exposed HTTP headers.
ExposeHeaders []string
// Max age of the CORS headers.
MaxAge time.Duration
}
Represents Access Control options.
func (*Options) IsOriginAllowed ¶
Looks up if the origin matches one of the patterns generated from Options.AllowOrigins patterns.
Click to show internal directories.
Click to hide internal directories.